@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Enrico M. Crisostomo
+ * Copyright (c) 2014-2024 Enrico M. Crisostomo
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -13,20 +13,20 @@
  * You should have received a copy of the GNU General Public License along with
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "libfswatch/libfswatch_config.h"
+#include <libfswatch/libfswatch_config.h>
 
 #ifdef HAVE_WINDOWS
 
 #  include "libfswatch/gettext_defs.h"
 #  include "windows_monitor.hpp"
-#  include "libfswatch_map.hpp"
-#  include "libfswatch_set.hpp"
 #  include "libfswatch_exception.hpp"
 #  include "libfswatch/c/libfswatch_log.h"
 #  include <algorithm>
 #  include <set>
 #  include <iostream>
 #  include <memory>
+#  include <unordered_map>
+#  include <unordered_set>
 #  include <sys/types.h>
 #  include <cstdlib>
 #  include <cstring>
@@ -47,9 +47,9 @@ namespace fsw
 {
   struct windows_monitor_load
   {
-    fsw_hash_set<wstring> win_paths;
-    fsw_hash_map<wstring, directory_change_event> dce_by_path;
-    fsw_hash_map<wstring, win_handle> event_by_path;
+    std::unordered_set<wstring> win_paths;
+    std::unordered_map<wstring, directory_change_event> dce_by_path;
+    std::unordered_map<wstring, win_handle> event_by_path;
     long buffer_size = 128;
   };
 
@@ -225,11 +225,9 @@ namespace fsw
 
     for (;;)
     {
-#ifdef HAVE_CXX_MUTEX
       unique_lock<mutex> run_guard(run_mutex);
       if (should_stop) break;
       run_guard.unlock();
-#endif
 
       sleep(latency);
 
